pub enum InjectError {
IllegalPath(ContainsNul<u16>),
Io(Error),
UnsupportedTarget,
RemoteIo(Error),
RemoteException(ExceptionCode),
ProcessInaccessible,
ArchitectureMismatch,
Goblin(Error),
}Available on crate feature
syringe only.Expand description
Error enum for errors during Syringe::inject.
Variants
IllegalPath(ContainsNul<u16>)
Variant representing an illegal interior nul value in the module path.
Io(Error)
Variant representing an io error.
UnsupportedTarget
Variant representing an unsupported target process.
RemoteIo(Error)
Variant representing an io error inside the target process.
RemoteException(ExceptionCode)
Variant representing an unhandled exception inside the target process.
ProcessInaccessible
Variant representing an inaccessible target process. This can occur if it crashed or was terminated.
ArchitectureMismatch
Variant representing an incompatible payload module compiled for a different target than the target process.
Goblin(Error)
Available on x86-64 and crate feature
into-x86-from-x64 only.Variant representing an error while loading an pe file.