pub enum SyringeError {
IllegalPath(ContainsNul<u16>),
Io(Error),
UnsupportedTarget,
RemoteIo(Error),
RemoteException(ExceptionCode),
ProcessInaccessible,
ArchitectureMismatch,
ModuleInaccessible,
Serde(SerdeError),
RemotePayloadProcedure(String),
Goblin(Error),
}syringe only.Expand description
Error enum encompassing all errors during Syringe operations.
Variants
IllegalPath(ContainsNul<u16>)
Variant representing an illegal interior nul value in the module path.
Io(Error)
Variant representing an io error.
UnsupportedTarget
Variant representing an unsupported target process.
RemoteIo(Error)
Variant representing an io error inside the target process.
RemoteException(ExceptionCode)
Variant representing an unhandled exception inside the target process.
ProcessInaccessible
Variant representing an inaccessible target process. This can occur if it crashed or was terminated.
ArchitectureMismatch
Variant representing an incompatible payload module compiled for a different target than the target process.
ModuleInaccessible
Variant representing an inaccessible target module. This can occur if the target module was ejected or unloaded.
Serde(SerdeError)
rpc-payload only.Variant representing an error while serializing or deserializing.
RemotePayloadProcedure(String)
rpc-payload only.Variant representing an error or panic inside a remote payload procedure.
Goblin(Error)
into-x86-from-x64 only.Variant representing an error while loading an pe file.