FunctionPtr

Trait FunctionPtr 

pub unsafe trait FunctionPtr:
    Sized
    + Copy
    + Send
    + Sync
    + 'static {
    type Args;
    type RefArgs<'a>;
    type Output;
    type NonExtern: FunctionPtr;

    const ARITY: usize;
    const ABI: Abi;

    // Required methods
    unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self;
    fn as_ptr(&self) -> RawFunctionPtr;
}
Available on Windows only.
Trait representing a function.

Safety

This trait should only be implemented for function pointers and the associated types and constants have to match the function pointer type.

Required Associated Constants

const ARITY: usize

The function’s arity (number of arguments).

const ABI: Abi

The ABI of this function.

Required Associated Types

type Args

The argument types as a tuple.

type RefArgs<'a>

The argument types as a tuple of references.

type Output

The return type.

type NonExtern: FunctionPtr

The non-extern version of the function pointer.

Required Methods

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Constructs a FunctionPtr from an untyped function pointer.

Safety

This function is unsafe because it can not check if the argument points to a function of the correct type.

fn as_ptr(&self) -> RawFunctionPtr

Returns a untyped function pointer for this function.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, L: 'static> FunctionPtr for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, L: 'static> FunctionPtr for extern "system" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, L: 'static> FunctionPtr for extern "win64" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, L: 'static> FunctionPtr for fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, L: 'static> FunctionPtr for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, L: 'static> FunctionPtr for unsafe extern "system" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, L: 'static> FunctionPtr for unsafe extern "win64" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, L: 'static> FunctionPtr for unsafe fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static> FunctionPtr for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static> FunctionPtr for extern "system" fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static> FunctionPtr for extern "win64" fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static> FunctionPtr for fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static> FunctionPtr for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static> FunctionPtr for unsafe extern "system" fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static> FunctionPtr for unsafe extern "win64" fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static> FunctionPtr for unsafe fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static> FunctionPtr for extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static> FunctionPtr for extern "system" fn(A, B, C, D, E, F, G, H, I, J) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static> FunctionPtr for extern "win64" fn(A, B, C, D, E, F, G, H, I, J) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static> FunctionPtr for fn(A, B, C, D, E, F, G, H, I, J) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static> FunctionPtr for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static> FunctionPtr for unsafe extern "system" fn(A, B, C, D, E, F, G, H, I, J) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static> FunctionPtr for unsafe extern "win64" fn(A, B, C, D, E, F, G, H, I, J) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static> FunctionPtr for unsafe fn(A, B, C, D, E, F, G, H, I, J) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static> FunctionPtr for extern "C" fn(A, B, C, D, E, F, G, H, I) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static> FunctionPtr for extern "system" fn(A, B, C, D, E, F, G, H, I) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static> FunctionPtr for extern "win64" fn(A, B, C, D, E, F, G, H, I) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static> FunctionPtr for fn(A, B, C, D, E, F, G, H, I) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static> FunctionPtr for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static> FunctionPtr for unsafe extern "system" fn(A, B, C, D, E, F, G, H, I) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static> FunctionPtr for unsafe extern "win64" fn(A, B, C, D, E, F, G, H, I) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static> FunctionPtr for unsafe fn(A, B, C, D, E, F, G, H, I) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static> FunctionPtr for extern "C" fn(A, B, C, D, E, F, G, H) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static> FunctionPtr for extern "system" fn(A, B, C, D, E, F, G, H) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static> FunctionPtr for extern "win64" fn(A, B, C, D, E, F, G, H) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static> FunctionPtr for fn(A, B, C, D, E, F, G, H) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static> FunctionPtr for unsafe extern "C" fn(A, B, C, D, E, F, G, H) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static> FunctionPtr for unsafe extern "system" fn(A, B, C, D, E, F, G, H) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static> FunctionPtr for unsafe extern "win64" fn(A, B, C, D, E, F, G, H) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static> FunctionPtr for unsafe fn(A, B, C, D, E, F, G, H) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static> FunctionPtr for extern "C" fn(A, B, C, D, E, F, G) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static> FunctionPtr for extern "system" fn(A, B, C, D, E, F, G) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static> FunctionPtr for extern "win64" fn(A, B, C, D, E, F, G) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static> FunctionPtr for fn(A, B, C, D, E, F, G) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static> FunctionPtr for unsafe extern "C" fn(A, B, C, D, E, F, G) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static> FunctionPtr for unsafe extern "system" fn(A, B, C, D, E, F, G) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static> FunctionPtr for unsafe extern "win64" fn(A, B, C, D, E, F, G) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static> FunctionPtr for unsafe fn(A, B, C, D, E, F, G) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static> FunctionPtr for extern "C" fn(A, B, C, D, E, F) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static> FunctionPtr for extern "system" fn(A, B, C, D, E, F) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static> FunctionPtr for extern "win64" fn(A, B, C, D, E, F) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static> FunctionPtr for fn(A, B, C, D, E, F) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static> FunctionPtr for unsafe extern "C" fn(A, B, C, D, E, F) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static> FunctionPtr for unsafe extern "system" fn(A, B, C, D, E, F) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static> FunctionPtr for unsafe extern "win64" fn(A, B, C, D, E, F) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static> FunctionPtr for unsafe fn(A, B, C, D, E, F) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static> FunctionPtr for extern "C" fn(A, B, C, D, E) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static> FunctionPtr for extern "system" fn(A, B, C, D, E) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static> FunctionPtr for extern "win64" fn(A, B, C, D, E) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static> FunctionPtr for fn(A, B, C, D, E) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static> FunctionPtr for unsafe extern "C" fn(A, B, C, D, E) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static> FunctionPtr for unsafe extern "system" fn(A, B, C, D, E) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static> FunctionPtr for unsafe extern "win64" fn(A, B, C, D, E) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static> FunctionPtr for unsafe fn(A, B, C, D, E) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static> FunctionPtr for extern "C" fn(A, B, C, D) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static> FunctionPtr for extern "system" fn(A, B, C, D) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static> FunctionPtr for extern "win64" fn(A, B, C, D) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static> FunctionPtr for fn(A, B, C, D) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static> FunctionPtr for unsafe extern "C" fn(A, B, C, D) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static> FunctionPtr for unsafe extern "system" fn(A, B, C, D) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static> FunctionPtr for unsafe extern "win64" fn(A, B, C, D) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static, D: 'static> FunctionPtr for unsafe fn(A, B, C, D) -> Ret

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static> FunctionPtr for extern "C" fn(A, B, C) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B, C)

Source

type RefArgs<'a> = (&'a A, &'a B, &'a C)

Source

type Output = Ret

Source

type NonExtern = fn(A, B, C) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static> FunctionPtr for extern "system" fn(A, B, C) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B, C)

Source

type RefArgs<'a> = (&'a A, &'a B, &'a C)

Source

type Output = Ret

Source

type NonExtern = fn(A, B, C) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static> FunctionPtr for extern "win64" fn(A, B, C) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B, C)

Source

type RefArgs<'a> = (&'a A, &'a B, &'a C)

Source

type Output = Ret

Source

type NonExtern = fn(A, B, C) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static> FunctionPtr for fn(A, B, C) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B, C)

Source

type RefArgs<'a> = (&'a A, &'a B, &'a C)

Source

type Output = Ret

Source

type NonExtern = fn(A, B, C) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static> FunctionPtr for unsafe extern "C" fn(A, B, C) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B, C)

Source

type RefArgs<'a> = (&'a A, &'a B, &'a C)

Source

type Output = Ret

Source

type NonExtern = fn(A, B, C) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static> FunctionPtr for unsafe extern "system" fn(A, B, C) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B, C)

Source

type RefArgs<'a> = (&'a A, &'a B, &'a C)

Source

type Output = Ret

Source

type NonExtern = fn(A, B, C) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static> FunctionPtr for unsafe extern "win64" fn(A, B, C) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B, C)

Source

type RefArgs<'a> = (&'a A, &'a B, &'a C)

Source

type Output = Ret

Source

type NonExtern = fn(A, B, C) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static, C: 'static> FunctionPtr for unsafe fn(A, B, C) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B, C)

Source

type RefArgs<'a> = (&'a A, &'a B, &'a C)

Source

type Output = Ret

Source

type NonExtern = fn(A, B, C) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static> FunctionPtr for extern "C" fn(A, B) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B)

Source

type RefArgs<'a> = (&'a A, &'a B)

Source

type Output = Ret

Source

type NonExtern = fn(A, B) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static> FunctionPtr for extern "system" fn(A, B) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B)

Source

type RefArgs<'a> = (&'a A, &'a B)

Source

type Output = Ret

Source

type NonExtern = fn(A, B) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static> FunctionPtr for extern "win64" fn(A, B) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B)

Source

type RefArgs<'a> = (&'a A, &'a B)

Source

type Output = Ret

Source

type NonExtern = fn(A, B) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static> FunctionPtr for fn(A, B) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B)

Source

type RefArgs<'a> = (&'a A, &'a B)

Source

type Output = Ret

Source

type NonExtern = fn(A, B) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static> FunctionPtr for unsafe extern "C" fn(A, B) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B)

Source

type RefArgs<'a> = (&'a A, &'a B)

Source

type Output = Ret

Source

type NonExtern = fn(A, B) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static> FunctionPtr for unsafe extern "system" fn(A, B) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B)

Source

type RefArgs<'a> = (&'a A, &'a B)

Source

type Output = Ret

Source

type NonExtern = fn(A, B) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static> FunctionPtr for unsafe extern "win64" fn(A, B) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B)

Source

type RefArgs<'a> = (&'a A, &'a B)

Source

type Output = Ret

Source

type NonExtern = fn(A, B) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static, B: 'static> FunctionPtr for unsafe fn(A, B) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A, B)

Source

type RefArgs<'a> = (&'a A, &'a B)

Source

type Output = Ret

Source

type NonExtern = fn(A, B) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static> FunctionPtr for extern "C" fn(A) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A,)

Source

type RefArgs<'a> = (&'a A,)

Source

type Output = Ret

Source

type NonExtern = fn(A) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static> FunctionPtr for extern "system" fn(A) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A,)

Source

type RefArgs<'a> = (&'a A,)

Source

type Output = Ret

Source

type NonExtern = fn(A) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static> FunctionPtr for extern "win64" fn(A) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A,)

Source

type RefArgs<'a> = (&'a A,)

Source

type Output = Ret

Source

type NonExtern = fn(A) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static> FunctionPtr for fn(A) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A,)

Source

type RefArgs<'a> = (&'a A,)

Source

type Output = Ret

Source

type NonExtern = fn(A) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static> FunctionPtr for unsafe extern "C" fn(A) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A,)

Source

type RefArgs<'a> = (&'a A,)

Source

type Output = Ret

Source

type NonExtern = fn(A) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static> FunctionPtr for unsafe extern "system" fn(A) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A,)

Source

type RefArgs<'a> = (&'a A,)

Source

type Output = Ret

Source

type NonExtern = fn(A) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static> FunctionPtr for unsafe extern "win64" fn(A) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A,)

Source

type RefArgs<'a> = (&'a A,)

Source

type Output = Ret

Source

type NonExtern = fn(A) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static, A: 'static> FunctionPtr for unsafe fn(A) -> Ret

Source

const ARITY: usize

Source

const ABI: Abi

Source

type Args = (A,)

Source

type RefArgs<'a> = (&'a A,)

Source

type Output = Ret

Source

type NonExtern = fn(A) -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static> FunctionPtr for extern "C" fn() -> Ret

Source

const ARITY: usize = 0

Source

const ABI: Abi

Source

type Args = ()

Source

type RefArgs<'a> = ()

Source

type Output = Ret

Source

type NonExtern = fn() -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static> FunctionPtr for extern "system" fn() -> Ret

Source

const ARITY: usize = 0

Source

const ABI: Abi

Source

type Args = ()

Source

type RefArgs<'a> = ()

Source

type Output = Ret

Source

type NonExtern = fn() -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static> FunctionPtr for extern "win64" fn() -> Ret

Source

const ARITY: usize = 0

Source

const ABI: Abi

Source

type Args = ()

Source

type RefArgs<'a> = ()

Source

type Output = Ret

Source

type NonExtern = fn() -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static> FunctionPtr for fn() -> Ret

Source

const ARITY: usize = 0

Source

const ABI: Abi

Source

type Args = ()

Source

type RefArgs<'a> = ()

Source

type Output = Ret

Source

type NonExtern = fn() -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static> FunctionPtr for unsafe extern "C" fn() -> Ret

Source

const ARITY: usize = 0

Source

const ABI: Abi

Source

type Args = ()

Source

type RefArgs<'a> = ()

Source

type Output = Ret

Source

type NonExtern = fn() -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static> FunctionPtr for unsafe extern "system" fn() -> Ret

Source

const ARITY: usize = 0

Source

const ABI: Abi

Source

type Args = ()

Source

type RefArgs<'a> = ()

Source

type Output = Ret

Source

type NonExtern = fn() -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static> FunctionPtr for unsafe extern "win64" fn() -> Ret

Source

const ARITY: usize = 0

Source

const ABI: Abi

Source

type Args = ()

Source

type RefArgs<'a> = ()

Source

type Output = Ret

Source

type NonExtern = fn() -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Source

impl<Ret: 'static> FunctionPtr for unsafe fn() -> Ret

Source

const ARITY: usize = 0

Source

const ABI: Abi

Source

type Args = ()

Source

type RefArgs<'a> = ()

Source

type Output = Ret

Source

type NonExtern = fn() -> Ret

Source

unsafe fn from_ptr(ptr: RawFunctionPtr) -> Self

Source

fn as_ptr(&self) -> RawFunctionPtr

Implementors