pub type RawFunctionPtrTarget = __some_function;Available on Windows only.
Type alias for the pointee of a raw function pointer.
Aliased Type
pub enum RawFunctionPtrTarget {}pub type RawFunctionPtrTarget = __some_function;Type alias for the pointee of a raw function pointer.
pub enum RawFunctionPtrTarget {}