ProcessMemorySlice

Struct ProcessMemorySlice 

pub struct ProcessMemorySlice<'a> { /* private fields */ }
Available on crate feature process-memory only.
A unowned slice of a buffer in the memory space of a (remote) process.

Implementations

Source

impl<'a> ProcessMemorySlice<'a>

pub const unsafe fn from_raw_parts( ptr: *mut u8, len: usize, process: BorrowedProcess<'a>, ) -> Self

Constructs a new slice from the given raw parts.

Safety

The caller must ensure that the designated region of memory

pub fn is_local(&self) -> bool

Returns whether the memory is allocated in the current process.

pub fn is_remote(&self) -> bool

Returns whether the memory is allocated in another process.

pub const fn process(&self) -> BorrowedProcess<'a>

Returns the process the buffer is allocated in.

pub const fn len(&self) -> usize

Returns the length of the buffer.

pub const fn is_empty(&self) -> bool

Returns whether the buffer is empty.

pub fn read(&self, offset: usize, buf: &mut [u8]) -> Result<(), Error>

Copies the contents of this buffer starting from the given offset to the given local buffer.

Panics

This function will panic if the given offset plus the given buffer length exceeds this buffer’s length.

pub unsafe fn read_struct<T>(&self, offset: usize) -> Result<T, Error>

Reads a value of type T from this buffer starting from the given offset.

Panics

This function will panic if the given offset plus the size of the value exceeds this buffer’s length.

Safety

The caller must ensure that the designated region of memory contains a valid instance of type T at the given offset.

pub fn write(&self, offset: usize, buf: &[u8]) -> Result<(), Error>

Copies the contents of the given local buffer to this buffer at the given offset.

Panics

This function will panic if the given offset plus the size of the local buffer exceeds this buffer’s length.

pub fn write_struct<T: ?Sized>(&self, offset: usize, s: &T) -> Result<(), Error>

Writes a value of type T to this buffer at the given offset.

Panics

This function will panic if the given offset plus the given buffer length exceeds this buffer’s length.

pub const fn as_ptr(&self) -> *mut u8

Returns a pointer to the start of the buffer.

Note

The returned pointer is only valid in the target process.

pub fn slice(&self, bounds: impl RangeBounds<usize>) -> Self

Returns a slice of this buffer.

pub fn as_local_slice(&self) -> Option<&[u8]>

Constructs a new slice spanning the whole buffer.

pub fn as_local_slice_mut(&mut self) -> Option<&mut [u8]>

Constructs a new mutable slice spanning the whole buffer.

pub fn flush_instruction_cache(&self) -> Result<(), Error>

Flushes the CPU instruction cache for the whole buffer. This may be necesary if the buffer is used to store dynamically generated code. For details see FlushInstructionCache.