BorrowedProcess

Struct BorrowedProcess 

pub struct BorrowedProcess<'a>(/* private fields */);
Available on Windows only.
A struct representing a running process. This struct does NOT own the underlying process handle (see also OwnedProcess for an owned version).

Note

The underlying handle has the following privileges:

  • PROCESS_CREATE_THREAD
  • PROCESS_QUERY_INFORMATION
  • PROCESS_VM_OPERATION
  • PROCESS_VM_WRITE
  • PROCESS_VM_READ

Implementations

Source

impl<'a> BorrowedProcess<'a>

pub fn try_to_owned(&self) -> Result<OwnedProcess, Error>

Tries to create a new OwnedProcess instance for this process.

pub fn module_handles( &self, ) -> Result<impl ExactSizeIterator<Item = ModuleHandle>, Error>

Returns a snapshot of the handles of the modules currently loaded in this process.

Note

If the process is currently starting up and has not yet loaded all its modules, the returned list may be incomplete. This can be worked around by repeatedly calling this method.