pub struct ProcessKillGuard(pub OwnedProcess);Available on Windows only.
A guard wrapping a OwnedProcess that will be automatically killed on drop.
Tuple Fields
0: OwnedProcessMethods from Deref<Target = OwnedProcess>
Sourcepub unsafe fn borrowed_static(&self) -> BorrowedProcess<'static>
pub unsafe fn borrowed_static(&self) -> BorrowedProcess<'static>
Returns a borrowed instance of this process that lives for 'static.
Safety
- This method is unsafe as the returned instance can outlive the owned instance, thus the caller must guarantee that the owned instance outlives the returned instance.