ProcessModule

Struct ProcessModule 

pub struct ProcessModule<P: Process> { /* private fields */ }
Available on Windows only.
A struct representing a loaded module of a running process.

Implementations

Source

impl<P: Process> ProcessModule<P>

pub unsafe fn new_unchecked(handle: ModuleHandle, process: P) -> Self

Contructs a new instance from the given module handle and its corresponding process.

Safety

The caller must guarantee that the given handle is valid and that the module is loaded into the given process. (and stays that way while using the returned instance).

pub unsafe fn new_local_unchecked(handle: ModuleHandle) -> Self

Contructs a new instance from the given module handle loaded in the current process.

Safety

The caller must guarantee that the given handle is valid and that the module is loaded into the given process. (and stays that way while using the returned instance).

pub fn borrowed(&self) -> BorrowedProcessModule<'_>

Returns a borrowed instance of this module.

pub fn find( module_name_or_path: impl AsRef<Path>, process: P, ) -> Result<Option<ProcessModule<P>>, IoOrNulError>

Searches for a module with the given name or path in the given process. If the extension is omitted, the default library extension .dll is appended.

pub fn find_by_name( module_name: impl AsRef<Path>, process: P, ) -> Result<Option<ProcessModule<P>>, IoOrNulError>

Searches for a module with the given name in the given process. If the extension is omitted, the default library extension .dll is appended.

pub fn find_by_path( module_path: impl AsRef<Path>, process: P, ) -> Result<Option<ProcessModule<P>>, IoOrNulError>

Searches for a module with the given path in the given process. If the extension is omitted, the default library extension .dll is appended.

pub fn find_local( module_name_or_path: impl AsRef<Path>, ) -> Result<Option<ProcessModule<P>>, IoOrNulError>

Searches for a module with the given name or path in the current process. If the extension is omitted, the default library extension .dll is appended.

pub fn find_local_by_name( module_name: impl AsRef<Path>, ) -> Result<Option<ProcessModule<P>>, IoOrNulError>

Searches for a module with the given name in the current process. If the extension is omitted, the default library extension .dll is appended.

pub fn find_local_by_path( module_path: impl AsRef<Path>, ) -> Result<Option<ProcessModule<P>>, IoOrNulError>

Searches for a module with the given path in the current process. If the extension is omitted, the default library extension .dll is appended.

pub fn handle(&self) -> ModuleHandle

Returns the underlying handle og the module.

pub fn process(&self) -> &P

Returns the process this module is loaded in.

pub fn is_local(&self) -> bool

Returns a value indicating whether the module is loaded in current process.

pub fn is_remote(&self) -> bool

Returns a value indicating whether the module is loaded in a remote process (not the current one).

pub fn path(&self) -> Result<PathBuf, Error>

Returns the path that the module was loaded from.

pub fn base_name(&self) -> Result<OsString, Error>

Returns the base name of the file the module was loaded from.

pub fn get_local_procedure_address( &self, proc_name: impl AsRef<str>, ) -> Result<RawFunctionPtr, GetLocalProcedureAddressError>

Returns a pointer to the procedure with the given name from this module.

Note

This function is only supported for modules in the current process.

pub unsafe fn get_local_procedure<F: FunctionPtr>( &self, proc_name: impl AsRef<str>, ) -> Result<F, GetLocalProcedureAddressError>

Returns a pointer to the procedure with the given name from this module.

Note

This function is only supported for modules in the current process.

Safety

The target function must abide by the given function signature.

pub fn guess_is_loaded(&self) -> bool

Returns whether this module is still loaded in the respective process. If the operation fails, the module is considered to be unloaded.

pub fn try_guess_is_loaded(&self) -> Result<bool, Error>

Returns whether this module is still loaded in the respective process.

Source

impl ProcessModule<BorrowedProcess<'_>>

pub fn try_to_owned(&self) -> Result<OwnedProcessModule, Error>

Tries to create a new OwnedProcessModule instance for this process module.