pub enum LoadProcedureError {
Io(Error),
UnsupportedTarget,
RemoteIo(Error),
RemoteException(ExceptionCode),
ProcessInaccessible,
ModuleInaccessible,
Goblin(Error),
}Available on crate feature
syringe only.Expand description
Error enum for errors during procedure loading.
Variants
Io(Error)
Variant representing an io error.
UnsupportedTarget
Variant representing an unsupported target process.
RemoteIo(Error)
Variant representing an io error inside the target process.
RemoteException(ExceptionCode)
Variant representing an unhandled exception inside the target process.
ProcessInaccessible
Variant representing an inaccessible target process. This can occur if it crashed or was terminated.
ModuleInaccessible
Variant representing an inaccessible target module. This can occur if the target module was ejected or unloaded.
Goblin(Error)
Available on x86-64 and crate feature
into-x86-from-x64 only.Variant representing an error while loading an pe file.